@@ -13,7 +13,7 @@ use Class::Adapter::Builder
 	NEW      => 'Wx::Menu',
 	AUTOLOAD => 'PUBLIC';
 
-our $VERSION = '0.47';
+our $VERSION = '0.48';
 
 use Class::XSAccessor getters => {
 	wx => 'OBJECT',
@@ -51,7 +51,6 @@ sub add_menu_item {
 	shift->_add_menu_item( 'Append', @_ );
 }
 
-
 # Add a checked menu item to menu from a Padre action
 sub add_checked_menu_item {
 	shift->_add_menu_item( 'AppendCheckItem', @_ );
@@ -62,6 +61,31 @@ sub add_radio_menu_item {
 	shift->_add_menu_item( 'AppendRadioItem', @_ );
 }
 
+# Add a normal menu item to menu from a existing Padre action
+sub add_menu_action {
+	my $self        = shift;
+	my $menu        = shift;
+	my $action_name = shift;
+
+	my $actions  = Padre->ide->actions;
+	my $action   = $actions->{$action_name};
+	my $name     = $action->name;
+	my $shortcut = $action->shortcut;
+	my $method   = $action->menu_method || 'Append';
+
+	my $item = $menu->$method(
+		$action->id,
+		$action->label_menu,
+	);
+	Wx::Event::EVT_MENU(
+		$self->{main},
+		$item,
+		$action->menu_event,
+	);
+
+	return $item;
+}
+
 # (Private method)
 # Add a normal/checked/radio menu item to menu from a Padre action
 sub _add_menu_item {
@@ -82,22 +106,8 @@ sub _add_menu_item {
 		$action->menu_event,
 	);
 
-	my $actions = Padre->ide->actions;
-	if ( $actions->{$name} ) {
-		warn "Found a duplicate action '$name'\n";
-	}
-
-	if ($shortcut) {
-		foreach my $n ( keys %$actions ) {
-			my $a = $actions->{$n};
-			next unless $a->shortcut;
-			next unless $a->shortcut eq $shortcut;
-			warn "Found a duplicate shortcut '$shortcut' with " . $a->name . " for '$name'\n";
-			last;
-		}
-	}
-
-	$actions->{$name} = $action;
+	# Adding actions to the main action hash has been moved to
+	# Action.pm for compatibility.
 
 	return $item;
 }
