@@ -9,7 +9,7 @@ use Padre::Current qw{_CURRENT};
 use Padre::Wx       ();
 use Padre::Wx::Menu ();
 
-our $VERSION = '0.47';
+our $VERSION = '0.48';
 our @ISA     = 'Padre::Wx::Menu';
 
 
@@ -135,6 +135,63 @@ sub new {
 		},
 	);
 
+	# Special copy
+	my $edit_copy = Wx::Menu->new;
+	$self->Append(
+		-1,
+		Wx::gettext("Copy specials"),
+		$edit_copy
+	);
+
+	$self->add_menu_item(
+		$edit_copy,
+		name       => 'edit.copy_filename',
+		label      => Wx::gettext('Copy full filename'),
+		menu_event => sub {
+			my $document = Padre::Current->document;
+			return if !defined( $document->{file} );
+			my $editor = Padre::Current->editor;
+			$editor->put_text_to_clipboard( $document->{file}->{filename} );
+		},
+	);
+
+	$self->add_menu_item(
+		$edit_copy,
+		name       => 'edit.copy_basename',
+		label      => Wx::gettext('Copy filename'),
+		menu_event => sub {
+			my $document = Padre::Current->document;
+			return if !defined( $document->{file} );
+			my $editor = Padre::Current->editor;
+			$editor->put_text_to_clipboard( $document->{file}->basename );
+		},
+	);
+
+	$self->add_menu_item(
+		$edit_copy,
+		name       => 'edit.copy_dirname',
+		label      => Wx::gettext('Copy directory name'),
+		menu_event => sub {
+			my $document = Padre::Current->document;
+			return if !defined( $document->{file} );
+			my $editor = Padre::Current->editor;
+			$editor->put_text_to_clipboard( $document->{file}->dirname );
+		},
+	);
+
+	$self->add_menu_item(
+		$edit_copy,
+		name       => 'edit.copy_content',
+		label      => Wx::gettext('Copy editor content'),
+		menu_event => sub {
+			my $document = Padre::Current->document;
+			return if !defined( $document->{file} );
+			my $editor = Padre::Current->editor;
+			$editor->put_text_to_clipboard( $document->text_get );
+		},
+	);
+
+	# Paste
 	$self->{paste} = $self->add_menu_item(
 		$self,
 		name       => 'edit.paste',
