@@ -9,7 +9,7 @@ use Padre::Wx       ();
 use Padre::Wx::Menu ();
 use Padre::Current qw{_CURRENT};
 
-our $VERSION = '0.47';
+our $VERSION = '0.48';
 our @ISA     = 'Padre::Wx::Menu';
 
 
@@ -30,74 +30,36 @@ sub new {
 	$self->{main} = $main;
 
 	# Script Execution
-	$self->{run_document} = $self->add_menu_item(
+	$self->{run_document} = $self->add_menu_action(
 		$self,
-		name       => 'run.run_document',
-		label      => Wx::gettext('Run Script'),
-		shortcut   => 'F5',
-		menu_event => sub {
-			$_[0]->run_document;
-			$_[0]->refresh_toolbar( $_[0]->current );
-		},
+		'run.run_document',
 	);
 
-	$self->{run_document_debug} = $self->add_menu_item(
+	$self->{run_document_debug} = $self->add_menu_action(
 		$self,
-		name       => 'run.run_document_debug',
-		label      => Wx::gettext('Run Script (debug info)'),
-		shortcut   => 'Shift-F5',
-		menu_event => sub {
-			$_[0]->run_document(1); # Enable debug info
-		},
+		'run.run_document_debug',
 	);
 
-	$self->{run_command} = $self->add_menu_item(
+	$self->{run_command} = $self->add_menu_action(
 		$self,
-		name       => 'run.run_command',
-		label      => Wx::gettext('Run Command'),
-		shortcut   => 'Ctrl-F5',
-		menu_event => sub {
-			$_[0]->on_run_command;
-		},
+		'run.run_command',
 	);
 
-	$self->{run_tests} = $self->add_menu_item(
+	$self->{run_tests} = $self->add_menu_action(
 		$self,
-		name       => 'run.run_tests',
-		label      => Wx::gettext('Run Tests'),
-		menu_event => sub {
-			$_[0]->on_run_tests;
-		},
+		'run.run_tests',
 	);
 
-	$self->{run_this_test} = $self->add_menu_item(
+	$self->{run_this_test} = $self->add_menu_action(
 		$self,
-		name       => 'run.run_this_test',
-		label      => Wx::gettext('Run This Test'),
-		menu_event => sub {
-			$_[0]->on_run_this_test;
-		},
+		'run.run_this_test',
 	);
 
 	$self->AppendSeparator;
 
-	$self->{stop} = $self->add_menu_item(
+	$self->{stop} = $self->add_menu_action(
 		$self,
-		name       => 'run.stop',
-		label      => Wx::gettext('Stop execution'),
-		shortcut   => 'F6',
-		menu_event => sub {
-			if ( $_[0]->{command} ) {
-				if (Padre::Constant::WIN32) {
-					$_[0]->{command}->KillProcess;
-				} else {
-					$_[0]->{command}->TerminateProcess;
-				}
-			}
-			delete $_[0]->{command};
-			$_[0]->refresh_toolbar( $_[0]->current );
-			return;
-		},
+		'run.stop',
 	);
 
 	# Initialise enabled
