@@ -5,19 +5,20 @@ use strict;
 use warnings;
 use Params::Util qw{_INSTANCE};
 use Padre::Current qw{_CURRENT};
-use Padre::Util              ();
-use Padre::Wx                ();
-use Padre::Wx::Menu::File    ();
-use Padre::Wx::Menu::Edit    ();
-use Padre::Wx::Menu::Search  ();
-use Padre::Wx::Menu::View    ();
-use Padre::Wx::Menu::Perl    ();
+use Padre::Util             ();
+use Padre::Wx               ();
+use Padre::Wx::Menu::File   ();
+use Padre::Wx::Menu::Edit   ();
+use Padre::Wx::Menu::Search ();
+use Padre::Wx::Menu::View   ();
+use Padre::Wx::Menu::Perl   ();
+use Padre::Wx::Menu::Refactor();
 use Padre::Wx::Menu::Run     ();
 use Padre::Wx::Menu::Plugins ();
 use Padre::Wx::Menu::Window  ();
 use Padre::Wx::Menu::Help    ();
 
-our $VERSION = '0.47';
+our $VERSION = '0.48';
 
 #####################################################################
 # Construction, Setup, and Accessors
@@ -28,15 +29,16 @@ use Class::XSAccessor getters => {
 
 	# Don't add accessors to here until they have been
 	# upgraded to be fully encapsulated classes.
-	file    => 'file',
-	edit    => 'edit',
-	search  => 'search',
-	view    => 'view',
-	perl    => 'perl',
-	run     => 'run',
-	plugins => 'plugins',
-	window  => 'window',
-	help    => 'help',
+	file     => 'file',
+	edit     => 'edit',
+	search   => 'search',
+	view     => 'view',
+	perl     => 'perl',
+	refactor => 'refactor',
+	run      => 'run',
+	plugins  => 'plugins',
+	window   => 'window',
+	help     => 'help',
 };
 
 sub new {
@@ -55,16 +57,17 @@ sub new {
 	}, $class;
 
 	# Generate the individual menus
-	$self->{main}    = $main;
-	$self->{file}    = Padre::Wx::Menu::File->new($main);
-	$self->{edit}    = Padre::Wx::Menu::Edit->new($main);
-	$self->{search}  = Padre::Wx::Menu::Search->new($main);
-	$self->{view}    = Padre::Wx::Menu::View->new($main);
-	$self->{perl}    = Padre::Wx::Menu::Perl->new($main);
-	$self->{run}     = Padre::Wx::Menu::Run->new($main);
-	$self->{plugins} = Padre::Wx::Menu::Plugins->new($main);
-	$self->{window}  = Padre::Wx::Menu::Window->new($main);
-	$self->{help}    = Padre::Wx::Menu::Help->new($main);
+	$self->{main}     = $main;
+	$self->{file}     = Padre::Wx::Menu::File->new($main);
+	$self->{edit}     = Padre::Wx::Menu::Edit->new($main);
+	$self->{search}   = Padre::Wx::Menu::Search->new($main);
+	$self->{view}     = Padre::Wx::Menu::View->new($main);
+	$self->{perl}     = Padre::Wx::Menu::Perl->new($main);
+	$self->{refactor} = Padre::Wx::Menu::Refactor->new($main);
+	$self->{run}      = Padre::Wx::Menu::Run->new($main);
+	$self->{plugins}  = Padre::Wx::Menu::Plugins->new($main);
+	$self->{window}   = Padre::Wx::Menu::Window->new($main);
+	$self->{help}     = Padre::Wx::Menu::Help->new($main);
 
 	# Generate the final menubar
 	$self->{wx} = Wx::MenuBar->new;
@@ -104,9 +107,11 @@ sub refresh {
 
 	# Add/Remove the Perl menu
 	if ( $perl and not $menu ) {
-		$self->wx->Insert( 4, $self->perl->wx, Wx::gettext("&Perl") );
+		$self->wx->Insert( 4, $self->perl->wx,     Wx::gettext("&Perl") );
+		$self->wx->Insert( 5, $self->refactor->wx, Wx::gettext("Ref&actor") );
 	} elsif ( $menu and not $perl ) {
-		$self->wx->Remove(4);
+		$self->wx->Remove(5); # refactor
+		$self->wx->Remove(4); # perl
 	}
 
 	# Refresh individual menus
@@ -120,6 +125,7 @@ sub refresh {
 	# unless we're actually showing it.
 	if ($perl) {
 		$self->perl->refresh($current);
+		$self->refactor->refresh($current);
 	}
 
 	# plugin menu requires special flag as it was leaking memory
@@ -144,9 +150,11 @@ sub refresh_top {
 
 	# Add/Remove the Perl menu
 	if ( $perl and not $menu ) {
-		$self->wx->Insert( 4, $self->perl->wx, Wx::gettext("&Perl") );
+		$self->wx->Insert( 4, $self->perl->wx,     Wx::gettext("&Perl") );
+		$self->wx->Insert( 5, $self->refactor->wx, Wx::gettext("Ref&actor") );
 	} elsif ( $menu and not $perl ) {
-		$self->wx->Remove(4);
+		$self->wx->Remove(5); # refactor
+		$self->wx->Remove(4); # perl
 	}
 
 	return 1;
